==> apache-camel-quarkus-2.9.0-src.zip: camel-quarkus-2.9.0/integration-tests/main-devmode/src/test/java/org/apache/camel/quarkus/main/CamelSupportResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.main;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.json.Json;
import javax.json.JsonArrayBuilder;
import javax.json.JsonObject;
import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

import org.apache.camel.CamelContext;

@Path("/test")
@ApplicationScoped
public class CamelSupportResource {
    @Inject
    CamelContext context;

    @Path("/describe")
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public JsonObject describeMain() {
        JsonArrayBuilder routes = Json.createArrayBuilder();
        context.getRoutes().forEach(route -> routes.add(route.getId()));

        return Json.createObjectBuilder()
                .add("routes", routes)
                .build();
    }

    @Path("/getShutdownStrategy")
    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String getShutdownStrategy() {
        return context.getShutdownStrategy().getClass().getSimpleName();
    }
}

==> apache-camel-quarkus-3.20.3-src.zip: camel-quarkus-3.20.3/integration-tests/main-devmode/src/test/java/org/apache/camel/quarkus/main/CamelSupportResource.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.main;

import jakarta.enterprise.context.ApplicationScoped;
import jakarta.inject.Inject;
import jakarta.json.Json;
import jakarta.json.JsonArrayBuilder;
import jakarta.json.JsonObject;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;
import org.apache.camel.CamelContext;

@Path("/test")
@ApplicationScoped
public class CamelSupportResource {
    @Inject
    CamelContext context;

    @Path("/describe")
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public JsonObject describeMain() {
        JsonArrayBuilder routes = Json.createArrayBuilder();
        context.getRoutes().forEach(route -> routes.add(route.getId()));

        return Json.createObjectBuilder()
                .add("routes", routes)
                .build();
    }

    @Path("/getShutdownStrategy")
    @GET
    @Produces(MediaType.TEXT_PLAIN)
    public String getShutdownStrategy() {
        return context.getShutdownStrategy().getClass().getSimpleName();
    }
}
